import React, { Component } from "react";
import Taro, { getCurrentInstance } from "@tarojs/taro";
import { Text, Picker, View } from "@tarojs/components";
import { AtInput, AtTextarea, AtButton, AtIcon } from "taro-ui";
import { detailsAdd } from "../../utils/servers/servers";
import "./index.less";

class AccountFrom extends Component {
  $instance = getCurrentInstance();

  constructor(props) {
    super(props);
    this.state = {
      type: 3,
      data: {},
      eaid: "",
      list: [
        { type: 0, postlist: ["amount"] },
        { type: 2, postlist: ["agreeTimes", "amount"] },
        {
          type: 3, postlist: ["agreeTimes", "payType", "invoiceType",
            "invoiceNo", "payerName", "openBank", "bankAccounts", "openBankAddress", "amount"]
        },
        { type: 4, postlist: ["agreeTimes", "amount"] },
        { type: 5, postlist: ["agreeTimes", "amount"] },
      ],
      toast: [
        { key: "agreeTimes", value: "请选择需付款时间！" },
        { key: "invoiceType", value: "请选择发票类型！" }, { key: "invoiceNo", value: "请填写发票号！" },
        { key: "payerName", value: "请填写付款单位！" }, { key: "openBank", value: "请填写开户银行！" },
        { key: "bankAccounts", value: "请填写银行账户！" }, { key: "openBankAddress", value: "请填写开户行地址！" },
        { key: "amount", value: "请填写金额！" },
      ],
    };

  }

  componentDidMount() {
    this.setState({
      type: this.$instance.router.params.type,
      eaid: this.$instance.router.params.id,
    })

  }

  getShow(type, name) {
    const { list } = this.state
    let display = "none"
    for (var i = 0; i < list.length; i++) {
      if (list[i].type == type) {
        for (var j = 0; j < list[i].postlist.length; j++) {
          if (list[i].postlist[j] == name) {
            display = "block"
          }
        }
      }
    }
    return display
  }

  onSubmit() {
    const { data, eaid, type, list, toast } = this.state
    // 校验必填
    for (var i = 0; i < list.length; i++) {
      if (list[i].type == type) {
        let newList = list[i].postlist
        for (var j = 0; j < newList.length; j++) {
          for (var k = 0; k < toast.length; k++) {
            if (newList[j] == toast[k].key && !data[newList[j]] && data[newList[j]] != 0) {
              Taro.showToast({
                title: toast[k].value,
                icon: "none",
              });
              return
            }
          }
        }
      }
    }

    let obj = {
      ...data,
      ...{ eaid, type, }
    }
    this.setState({
      loading: true,
    });
    detailsAdd(obj)
      .then((v) => {
        this.setState({
          loading: false,
        });
        if (v.error.length === 0) {
          Taro.showToast({
            title: "保存成功！",
            icon: "none",
          });
          const _this = this
          setTimeout(function () {
            Taro.navigateBack();
            _this.setState({
              loading: false,
            });
          }, 400);
        } else {
          Taro.showToast({
            title: v.error[0].message,
            icon: "none",
          });
        }
      })
      .catch(() => {
        this.setState({
          loading: false,
        });
      });
  }

  render() {
    const { type, data } = this.state
    const pickerList = ["普票", "专票"]
    return (
      <View className="accountFrom">
        {/* <View className="textareaFormItem" style={{ display: this.getShow(type, "remarks") }}>
          <AtTextarea
            value={data.remarks}
            onChange={e => {
              let obj = { remarks: e }
              this.setState({ data: { ...data, ...obj } })
            }}
            maxLength={50}
            placeholder="请填写报销事由"
          />
        </View> */}
        <View className="inputFormItem" style={{ display: this.getShow(type, "agreeTimes") }}>
          <View className="ifCustom">
            <View className="iftitle">需付款时间:</View>
            <Picker
              mode='date'
              onChange={(e) => {
                let obj = { agreeTimes: e.detail.value }
                this.setState({ data: { ...data, ...obj } })
              }}
            >
              <View className='picker'>
                {!data.agreeTimes ? <View className="ifvalues">点击选择</View> : <View className="ifvalue">{data.agreeTimes}</View>}
              </View>
            </Picker>
          </View>
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "payType") }}>
          <View className="ifCustom">
            <View className="iftitle">付款方式:</View>
            <Picker
              value={data.payType}
              range={["公对公转账"]} mode='selector'
              onChange={e => {
                const obj = { payType: e.detail.value }
                this.setState({
                  data: { ...data, ...obj }
                })
              }}
            >
              {
                data.payType == 0
                  ? <View className="ifvalue">公对公转账户</View>
                  : <View className="ifvalues">点击选择</View>
              }
            </Picker>
          </View>
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "invoiceType") }}>
          <View className="ifCustom">
            <View className="iftitle">发票类型:</View>
            <Picker
              value={data.invoiceType}
              range={pickerList} mode='selector'
              onChange={e => {
                const obj = { invoiceType: e.detail.value }
                this.setState({
                  data: { ...data, ...obj }
                })
              }}
            >
              {
                data.invoiceType == 0
                  ? <View className="ifvalue">普票</View> : data.invoiceType == 1
                    ? <View className="ifvalue">专票</View> : <View className="ifvalues">点击选择</View>
              }
            </Picker>
          </View>
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "invoiceNo") }}>
          <AtInput
            name='invoiceNo'
            title='发票号:'
            type='text'
            placeholder='请填写发票号'
            value={data.invoiceNo}
            onChange={e => {
              const obj = { invoiceNo: e }
              this.setState({
                data: { ...data, ...obj }
              })
            }}
          />
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "payerName") }}>
          <AtInput
            name='payerName'
            title='付款单位:'
            type='text'
            placeholder='请填写付款单位'
            value={data.payerName}
            onChange={e => {
              const obj = { payerName: e }
              this.setState({
                data: { ...data, ...obj }
              })
            }}
          />
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "openBank") }}>
          <AtInput
            name='openBank'
            title='开户银行:'
            type='text'
            placeholder='请填写开户银行'
            value={data.openBank}
            onChange={e => {
              const obj = { openBank: e }
              this.setState({
                data: { ...data, ...obj }
              })
            }}
          />
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "bankAccounts") }}>
          <AtInput
            name='bankAccounts'
            title='银行账户:'
            type='text'
            placeholder='请填写银行账户'
            value={data.bankAccounts}
            onChange={e => {
              const obj = { bankAccounts: e }
              this.setState({
                data: { ...data, ...obj }
              })
            }}
          />
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "openBankAddress") }}>
          <AtInput
            name='openBankAddress'
            title='开户行地址:'
            type='text'
            placeholder='请填写开户行地址'
            value={data.openBankAddress}
            onChange={e => {
              const obj = { openBankAddress: e }
              this.setState({
                data: { ...data, ...obj }
              })
            }}
          />
        </View>
        <View className="inputFormItem" style={{ display: this.getShow(type, "amount") }}>
          <AtInput
            name='amount'
            title={type == 4 ? "借支金额:" : "金额:"}
            type='text'
            placeholder='请填写金额（元）'
            value={data.amount}
            onChange={e => {
              const obj = { amount: e }
              this.setState({
                data: { ...data, ...obj }
              })
            }}
          />
        </View>
        <View className="bottom">
          <AtButton
            loading={this.state.loading}
            disabled={this.state.loading}
            type="primary"
            circle
            onClick={() => {
              this.onSubmit()
            }}
          >
            保存
          </AtButton>
        </View>
      </View>
    );
  }
}

export default AccountFrom;
