import React, { Component } from "react";
import Taro from "@tarojs/taro";
import { View, Image, Button } from "@tarojs/components";
import Skeleton from "taro-skeleton";
import { getClockState } from "../../utils/tools";
import { selectByPrid, creatOrder } from '../../utils/servers/servers';
import ListBottomStart from "../../components/common/listBottomStart";
import InquiryModal from "../../components/common/inquiryModal";
import Select from "../applyReimbursement/select";
import "./index.less";

class List extends Component {
  constructor(props) {
    super(props);
    this.state = {
      id: "",
      visible: "",
    };
  }

  onClose() {
    this.setState({
      visible: "",
    })
  }

  // 公出报销查询
  getByDrafts(id) {
    selectByPrid({
      prid: id,
      status: 0, //  0=草稿，1=审核中，2=完成，3=驳回
    }).then((v) => {
      if (v.error.length === 0) {
        if (v.data) {
          // 1有草稿未提交
          Taro.navigateTo({
            url: '/pages/drafts/index?id=' + v.data
          })
        } else {
          this.creatOrder(id)
          // this.setState({
          //   id,
          //   visible: "add",
          // })
        }
      } else {
        Taro.showToast({ title: v.error[0].message, icon: "none" });
      }
    }).catch((err) => {
      // Taro.showToast({ title: "系统错误,请稍后再试", icon: "none" });
    });
  }

  // 发起差旅费报销
  creatOrder(prid) {
    creatOrder({
      prid,
      type: 1,
    }).then(v => {
      if (v.error.length === 0) {
        Taro.redirectTo({
          url: '/pages/drafts/index?id=' + v.data
        })
      } else {
        Taro.showToast({ title: v.error[0].message, icon: 'none' })
      }
    }).catch(() => {
      Taro.showToast({
        title: '系统错误,请稍后再试',
        icon: 'none'
      })
    })
  }

  render() {
    return (
      <View className="indexPage">
        <View className="list">
          {
            this.props.list.length === 0 && this.props.listState === "LOADING" &&
            this.props.typelist?.map((v) => (
              <Skeleton key={v} title row={3} avatarShape="square" loading />
            ))
          }
          {this.props.list.length > 0 && this.props.list?.map((v, k) => (
            <View key={k} className="item">
              <View className="infor">
                <View className="title">
                  <View className="aname">
                    {v.aname}提交的公出申请
                    {v.updateStatus == 1 && <View className="aIcon">改</View>}
                  </View>
                  <View className="createTimes">{v.createTimes}</View>
                </View>
                <View className="userName">
                  <View className="uNtext">
                    公出企业:{v.userNames}
                  </View>
                </View>
                <View className="userName">
                  <View className="uNtext">
                    公出地点:{v.districtName}
                  </View>
                </View>
                <View className="releaseStarts">
                  开始时间:{v.releaseStarts}
                </View>
                {
                  v.status == 2 &&
                  <View
                    className="punchClock"
                    onClick={() => {
                      this.setState({
                        isInquiryOpened: true,
                        inquiryTitle: "温馨提醒",
                        inquiryContent: "您确定要发起此次公出费用报销吗?",
                        inquiryFn: () => {
                          this.getByDrafts(v.id)
                        },
                      });
                    }}
                  >
                    发起报销
                  </View>
                }
                <View className="releaseEnds">
                  结束时间:{v.releaseEnds}
                </View>
                {
                  v.assistAidName != null && v.assistAidName != "" &&
                  <View className="coOder">
                    技术协单:{v.assistAidName.replace(/,/g, " ")}
                  </View>
                }
                {
                  v.assistantName != null && v.assistantName != "" &&
                  <View className="coOder">
                    协单助手:{v.assistantName.replace(/,/g, " ")}
                  </View>
                }
                <View className="examine">{v.adminExamine}</View>
                <View className="bottomContent">
                  <View className="clockIn"
                    style={{ color: ['red', "#6eb173", '#dbc037'][v.clockIn] }}
                  >{['未打卡', '已打卡', '异常打卡'][v.clockIn]}</View>
                  <View
                    className="status"
                    style={{ color: getClockState(v.status).color, }}
                  >
                    {(v.status === 0 || v.status === 4) && v.rejectName}{getClockState(v.status).title}
                  </View>
                </View>
              </View>
            </View>
          ))}
          <ListBottomStart
            state={this.props.listState}
            reload={() => {
              this.props.onRefresh;
            }}
          />
        </View>
        {/* 二级确认弹窗 */}
        <InquiryModal
          isOpened={this.state.isInquiryOpened}
          title={this.state.inquiryTitle}
          content={this.state.inquiryContent}
          onClose={() => {
            this.setState({
              isInquiryOpened: false,
              inquiryTitle: "",
              inquiryContent: "",
              isNo: true,
            });
          }}
          onDetermine={() => {
            this.state.inquiryFn();
            this.setState({
              isInquiryOpened: false,
              inquiryTitle: "",
              inquiryContent: "",
              isNo: true,
              inquiryFn: () => { },
            });
          }}
        />
        {/* 发起报销类型选择 */}
        {/* {this.state.visible != "" &&
          <Select
            prid={this.state.id}
            visible={this.state.visible}
            onClose={this.onClose.bind(this)}
          />} */}

      </View>
    );
  }
}

export default List;
